#!/bin/csh -f                                                                   
# procedure to run new CSearch
if ($#argv == 0 ) then
   echo "You must specify the type of Run: recepp.s  RUN_TYPE (+ ARGUMENTS)"
   echo "Where RUN_TYPE is  one of the followings: "
   echo "       ENERGY"
   echo "       CHECKGRAD"
   echo "       MINIMIZE"
   echo "       EDMC"
   echo "       RMS_FIT"
   echo "       BOUNDS"
   echo "       VTF"
   exit (1)
endif
setenv RUNTYP $1
setenv RUN  "TYPE0"
if ( $1 == "ENERGY" ) then
setenv RUN  "TYPE1"
endif
if ( $1 == "CHECKGRAD" ) then
setenv RUN  "TYPE1"
endif
if ( $1 == "MINIMIZE" ) then
setenv RUN  "TYPE1"
endif
if ( $1 == "EDMC" ) then
setenv RUN  "TYPE1"
endif
if ( $1 == "RMS_FIT" ) then
setenv RUN  "TYPE2"
endif
if ( $1 == "BOUNDS" ) then
setenv RUN  "TYPE2"
endif
if ( $1 == "VTF" ) then
setenv RUN  "TYPE1"
endif
if ( $RUN == "TYPE0" ) then
   echo "Unrecognized option " $1
   echo "You must specified: recepp.s  RUN_TYPE (+ ARGUMENTS)"
   echo "Where RUN_TYPE is  one of the followings: "
   echo "       ENERGY"
   echo "       CHECKGRAD"
   echo "       MINIMIZE"
   echo "       EDMC"
   echo "       RMS_FIT"
   echo "       BOUNDS"
   echo "       VTF"
   exit (1)
endif
if ( $RUN == "TYPE1" ) then
 if ($#argv < 6 ) then
   echo "Missing argument(s)! "
   echo "You must enter:  recepp.s " $1 " ARG2 ARG3 ARG4 ARG5 "
   echo "ARG2  is the FILENAME of INPUT (*.inp) file (Input for the run)."
   echo "ARG3  is the FILETYPE of OUTPUT files."
   echo "ARG4  is the FILENAME of the ECEPP (outo.*) input file (if any) "
   echo "         or a Dummy Argument "
   echo "ARG5  is the FILETYPE of Constraints (bounds.*) files or a "
   echo "         Dummy argument if no constraints are used."
   echo "ARG6  is the number of Processors requested"
   exit (1)
 endif
 setenv BNDF $5
 setenv ANAF $4
 setenv MP_PROCS $6
endif
if ( $RUN == "TYPE2" ) then
 if ( $1 == "RMS_FIT" ) then
   if ($#argv < 6 ) then
      echo "Missing argument(s)! "
      echo "You must enter:   recepp.s " $1 " ARG2 ARG3 ARG4 ARG5 "
      echo "ARG2  is the FILENAME of INPUT (*.inp) file (Input for the run)."
      echo "ARG3  is the FILETYPE of OUTPUT files."
      echo "ARG4  is the FILENAME of the PDB or ECEPP (outo.*) input file."
      echo "ARG5  is the FILENAME of the Reference (xray.*) file."
      echo "ARG6  is the number of Processors requested"
      exit (1)
   endif
   setenv ANAF $4
   setenv REFF $5
   setenv MP_PROCS $6
 endif
 if ( $1 == "BOUNDS" ) then
   if ($#argv < 5 ) then
      echo "Missing argument(s)! "
      echo "You must enter:   recepp.s " $1 " ARG2 ARG3 ARG4 "
      echo "ARG2  is the FILENAME of INPUT (*.inp) file (Input for the run)."
      echo "ARG3  is the FILETYPE of OUTPUT files."
      echo "ARG4  is the FILENAME of the PDB input file."
      echo "ARG5  is the number of Processors requested"
      exit (1)
   endif
   setenv ANAF $4
   setenv MP_PROCS $5
 endif
endif

setenv INPF $2
setenv OUTF $3

echo $1 " CALCULATION"

# IF names of files are too large (more than 64 characters) program won't run. In this case,
# it is possible to create a symbolic link to the appropriate directory. 
ln -s "$ECEPP_ROOT" ECEPP_ROOTA

#  ********   GENERAL INPUT FILES  *************

#  Input for distance constraints
# ln -s bounds.$BNDF fort.7

# The following is the standard input file.
# ln -s $INPF.inp fort.8

# Input file containing the series of conformations whose energies
# must be evaluated or minimized ("MULT_CONF" control card).
# ln -s  outo.$ANAF  fort.11

#              INPUTS FOR SURFACE AREA AND HYDRATION
#  Parameters giving the free energy density for various solute atoms radii. 
# ln -s  $ECEPP_ROOT/data/Hydration_files/srfopt.set fort.23
#setenv  SOLVDBS  ECEPP_ROOTA/data/Hydration_files/
setenv  SOLVDBS  ECEPP_ROOTA/Data/Hydration
#setenv  SOLVFILE  ECEPP_ROOTA/data/Hydration_files/srfopt.set 
setenv  SOLVFILE  $SOLVDBS/srfopt.set 
 
# rsdata.aug95 is a version of the STANDARD AMINO ACID DICTIONARY
#              containing the ECEPP/3 residues and other non-standard ones.
#              NP in PRO's was replaced by N to increase compatibility
#              with PDB files.
#
#              Atom type of protons in COOH groups ( ASP, GLU, meASP, meGLU
#              and Carboxyl end terminal) changed to type 1, as in ECEPP/3
#              (no H-bonding allowed).
#
# passing database directory to program
setenv RSDBS  ${ECEPP_ROOT}/Data/Residue/
#setenv RSDBS  ECEPP_ROOTA/data/Residue_data_files/

# ln -s $ECEPP_ROOTA/data/Residue_data_files/rsdata.aug95 fort.35
#setenv RSDATA  ECEPP_ROOTA/data/Residue_data_files/rsdata.aug95
#setenv RSDATA ECEPP_ROOTA/Data/Residue/rsdata.new.crc
setenv RSDATA ECEPP_ROOTA/Data/Residue/rsdata.new


# File defining proton labels for each residue (for NMR purposes).   
# ln -s $ECEPP_ROOT/data/Residue_data_files/nmr_protons.data fort.33
#setenv HLABELFILE ECEPP_ROOTA/data/Residue_data_files/nmr_protons.data 
setenv HLABELFILE ECEPP_ROOTA/Data/Residue/nmr_protonsT.data 

# Parameters for the unified residue approximation, the radius of 
# each residue in the sequence. NOT IMPLEMENTED ON THIS VERSION  DR 2-94 
# RESRAD = UNIT 37
# ln -s resrad.data fort.37

# Atomic charges for IBEM

# ln -s  $ECEPP_ROOTA/data/IBEM/atcrg.crg fort.10
#setenv IBEMCHG ECEPP_ROOTA/data/IBEM/atcrg.crg 
setenv IBEMCHG ECEPP_ROOTA/Data/IBEM/atcrg.crg 

# Atomic radii for IBEM

#  ln -s $ECEPP_ROOTA/data/IBEM/atrad.siz fort.29
#setenv ATMRAD ECEPP_ROOTA/data/IBEM/atrad.siz 
setenv ATMRAD ECEPP_ROOTA/Data/IBEM/atrad.siz 

# Run parameters for IBEM

# ln -s ECEPP_ROOTA/data/IBEM/input.ibe fort.1
#setenv IBEINFILE ECEPP_ROOTA/data/IBEM/input.ibe 
setenv IBEINFILE ECEPP_ROOTA/Data/IBEM/input.ibe 

#  **********************************************      

# /  ********* GENERAL OUTPUT FILES *********/

# ln -s outo.$OUTF fort.4
# ln -s standout.$OUTF fort.6
# ln -s sumsl.$OUTF  fort.9

# Output file for BOUNDS  runs.
# ln -s bounds.$OUTF fort.12
# ln -s main_out.$OUTF fort.20

# IBEM List file 

# ln -s ibe.$OUTF fort.2
setenv IBEOUTFILE $OUTF 

# Be aware that UNIT 30 is used to print cartesian coordinates in OUTNW
# routine. It is not assigned by this script.

# The following definition can be used to print the APS matrix (Ken Gibson's
# compact form of the VDW and RO parameters), from BD11 subroutine.
# Write statement is currently commented out.
# ln -s  APS.$2 FILE.FT91F001

# print identification of files
echo "Input file: $INPF.inp"
echo "Identification string for output files: $OUTF"


#  Area optimization, the target areas for each residue in the sequence.
#  TGTARS = UNIT 38
setenv TGTARS TARGET.tgtars
 
#
#/* ******* INPUT-OUTPUT FILES ******** */
# ln -s edmc.rstart fort.17
setenv RESTFILE  edmc.rstart
# ln -s edmc.rndom fort.18
setenv RANDFILE edmc.rndom


if ( $RUN == "TYPE2" ) then

#  **********************************************      
# /* INPUT FILES RMS */
#
# Input conformation used to generate a REFERENCE file.
# ln -s  $REFF.pdb fort.27

# This file contains the REFERENCE conformation.
# ln -s  xray.$REFF fort.57

# When comparing two pdb files the input file is assigned to unit 44.
# The program will compare the conformation on this file with (a) the one 
# in UNIT 57 (xray.*); or (b) that in UNIT 27.
# ln -s  $ANAF.pdb   fort.44

# /* OUTPUT FILES RMS */

# ln -s  sidev.$OUTF  fort.22
# ln -s  hedev.$OUTF  fort.26
# ln -s  badev.$OUTF  fort.31
# ln -s   rgyr.$OUTF  fort.34
# ln -s   xray.$OUTF  fort.39
# ln -s chefol.$OUTF  fort.46
# ln -s  comso.$OUTF  fort.47
# ln -s  cmsdk.$OUTF  fort.48
# ln -s  kmsba.$OUTF  fort.49
#  **********************************************      
endif

# The name of the ECEPPAK executable goes here:
#edmX
$ECEPP_ROOT/bin/eceppak-$ECEPP_ARCH

endif
# it is possible to create a symbolic link to the appropriate directory. 
/bin/rm ECEPP_ROOTA
#/bin/rm fort.*
